pub trait Write<Output: AsMut<[u8]> + ?Sized> {
// Required method
fn write(self, buffer: &mut Output) -> Option<&[u8]>;
}Required Methods
Sourcefn write(self, buffer: &mut Output) -> Option<&[u8]>
fn write(self, buffer: &mut Output) -> Option<&[u8]>
If there is enough space, write to the Output and return the slice written to. Buffer contents can be anything if None is returned, and can be anything outside the slice.